@@ -1,2 +1,2 @@
-from .dataset import TfDatasetGenerator
+from .dataset import TFDatasetGenerator
 from .extractor import FeatureExtractor
