@@ -1,8 +1,7 @@
 from abc import abstractmethod
-from typing import Any
 
 import numpy as np
-from sklearn.base import BaseEstimator, TransformerMixin, _OneToOneFeatureMixin
+from sklearn.base import BaseEstimator, TransformerMixin
 
 from rexify.constants import SUPPORTED_DATA_TYPES
 from rexify.exceptions.schema import (
@@ -13,6 +12,7 @@ from rexify.exceptions.schema import (
     MissingKeysSchemaException,
     TooManyIdFeaturesSchemaException,
 )
+from rexify.types import Schema
 
 
 class BaseTransformer(BaseEstimator, TransformerMixin):
@@ -32,11 +32,13 @@ class HasSchemaInput:
             the user, item and context features
     """
 
-    def __init__(
-        self, schema: dict[str, dict[str, Any] | list[dict[str, str | float]]]
-    ):
+    def __init__(self, schema: Schema):
         self._validate_schema(schema)
-        self.schema = schema
+        self._schema = schema
+
+    @property
+    def schema(self):
+        return self._schema
 
     @staticmethod
     def _validate_schema(schema):
@@ -66,12 +68,3 @@ class HasSchemaInput:
                 ~np.in1d(list(schema["context"].values()), SUPPORTED_DATA_TYPES)
             ):
                 raise DataTypeNotSupportedSchemaException()
-
-
-class PassthroughTransformer(BaseTransformer, _OneToOneFeatureMixin):
-    def fit(self, X, *_):
-        self._validate_data(X, dtype=[str, float])
-        return self
-
-    def transform(self, X):
-        return X
